@@ -109,12 +109,6 @@ formatting = {
         pyatspi.ROLE_ANIMATION: {
             'unfocused': 'labelAndName'
             },
-        pyatspi.ROLE_CANVAS: {
-            'focused': 'labelAndName + imageDescription + roleName + positionInList',
-            'unfocused': 'labelAndName + imageDescription + roleName + positionInList',
-            'basicWhereAmI': 'parentRoleName + labelAndName + selectedItemCount',
-            'detailedWhereAmI': 'parentRoleName + labelAndName + selectedItemCount + selectedItems'
-            },
         pyatspi.ROLE_CHECK_BOX: {
             'focused': 'checkedState',
             'unfocused': 'labelAndName + roleName + checkedState + required + availability + ' + MNEMONIC + ' + accelerator',
@@ -179,10 +173,6 @@ formatting = {
             'unfocused': 'labelAndName + roleName + availability + ' + MNEMONIC,
             'basicWhereAmI': 'linkInfo + siteDescription + fileSize + ' + MNEMONIC
             },
-        pyatspi.ROLE_LIST: {
-            'focused': 'focusedItem',
-            'unfocused': 'labelOrName + focusedItem + multiselectableState + numberOfChildren'
-            },
         pyatspi.ROLE_LIST_ITEM: {
             'focused': 'expandableState + availability',
             'unfocused': 'labelAndName + allTextSelection + expandableState + availability + positionInList',
@@ -248,9 +238,19 @@ formatting = {
             'detailedWhereAmI': 'label + readOnly + textRole + textContentWithAttributes + anyTextSelection + ' + MNEMONIC + ' + ' + TUTORIAL
             },
         pyatspi.ROLE_SLIDER: {
+            # Ignore the text on the slider.  See bug 340559
+            # (http://bugzilla.gnome.org/show_bug.cgi?id=340559): the
+            # implementors of the slider support decided to put in a
+            # Unicode left-to-right character as part of the text,
+            # even though that is not painted on the screen.
+            #
+            # In Java, however, there are sliders without a label. In
+            # this case, we'll add to presentation the slider name if
+            # it exists and we haven't found anything yet.
+            #
             'focused': 'value',
-            'unfocused': 'labelOrName + roleName + value + required + availability + ' + MNEMONIC,
-            'basicWhereAmI': 'labelOrName + roleName + value + percentage + ' + MNEMONIC + ' + accelerator + required'
+            'unfocused': 'label + roleName + value + required + availability + ' + MNEMONIC,
+            'basicWhereAmI': 'label + roleName + value + percentage + ' + MNEMONIC + ' + accelerator + required'
             },
         pyatspi.ROLE_SPIN_BUTTON: {
             'focused': 'name',
@@ -365,10 +365,6 @@ formatting = {
                                      asString(label + displayedText + roleName + (description and space(": ") + description)))]',
             },
         #pyatspi.ROLE_ARROW: 'default'
-        pyatspi.ROLE_CANVAS: {
-            'unfocused': '[Component(obj,\
-                                     asString(((label + displayedText + imageDescription) or name) + roleName))]'
-            },
         pyatspi.ROLE_CHECK_BOX: {
             'unfocused': '[Component(obj,\
                                      asString(label + displayedText + roleName),\
@@ -428,11 +424,7 @@ formatting = {
                                      or asString(displayedText)\
                                      or asString(name))]',
         },
-        pyatspi.ROLE_LIST: {
-            'unfocused': '[Component(obj,\
-                                     asString(label + focusedItem + roleName),\
-                                     asString(label) and (len(asString(label)) + 1) or 0)]'
-        },
+        #pyatspi.ROLE_LIST: 'default'
         pyatspi.ROLE_LIST_ITEM: {
             'focused':   '[Component(obj,\
                                      asString(label + displayedText + expandableState + roleName + availability) + asString(accelerator))]\
@@ -499,7 +491,7 @@ formatting = {
         #'REAL_ROLE_SCROLL_PANE': 'default'
         pyatspi.ROLE_SLIDER: {
             'unfocused': '[Component(obj,\
-                                     asString(labelOrName + value + roleName + required))]'
+                                     asString(label + value + roleName + required))]'
             },
         pyatspi.ROLE_SPIN_BUTTON: {
             'unfocused': '[Text(obj, asString(label), asString(eol))]\
@@ -547,12 +539,6 @@ formatting = {
 }
 
 if settings.useExperimentalSpeechProsody:
-    formatting['speech'][pyatspi.ROLE_CANVAS]['focused'] = 'labelAndName + imageDescription + roleName + pause + positionInList'
-    formatting['speech'][pyatspi.ROLE_CANVAS]['unfocused'] = 'labelAndName + imageDescription + roleName + pause + positionInList'
-    formatting['speech'][pyatspi.ROLE_CANVAS]['basicWhereAmI'] = \
-        'parentRoleName + pause + labelAndName + pause + selectedItemCount + pause'
-    formatting['speech'][pyatspi.ROLE_CANVAS]['detailedWhereAmI'] = \
-        'parentRoleName + pause + labelAndName + pause + selectedItemCount + pause + selectedItems + pause'
     formatting['speech'][pyatspi.ROLE_CHECK_MENU_ITEM]['unfocused'] = \
         'labelAndName + roleName + checkedState + required + availability + ' + MNEMONIC + ' + accelerator + pause + positionInList'
     formatting['speech'][pyatspi.ROLE_CHECK_MENU_ITEM]['basicWhereAmI'] = \
@@ -577,8 +563,6 @@ if settings.useExperimentalSpeechProsody:
         'labelAndName + pause + roleName + pause + selectedItemCount + pause+ selectedItems + pause'
     formatting['speech'][pyatspi.ROLE_LINK]['basicWhereAmI'] = \
         'linkInfo + pause + siteDescription + pause + fileSize + pause + ' + MNEMONIC
-    formatting['speech'][pyatspi.ROLE_LIST]['unfocused'] = \
-        'labelOrName + pause + focusedItem + pause + multiselectableState + numberOfChildren + pause'
     formatting['speech'][pyatspi.ROLE_LIST_ITEM]['unfocused'] = \
         'labelAndName + allTextSelection + pause + expandableState + pause + availability + positionInList'
     formatting['speech'][pyatspi.ROLE_LIST_ITEM]['basicWhereAmI'] = \
@@ -636,8 +620,8 @@ class Formatting(dict):
             if key in self:
                 if isinstance(self[key], dict) and isinstance(val, dict):
                     self[key].update(val)
-                elif isinstance(self[key], basestring) \
-                     and isinstance(val, basestring):
+                elif isinstance(self[key], str) \
+                     and isinstance(val, str):
                     self[key] = val
                 else:
                     # exception or such like, we are trying to murge
