@@ -262,36 +262,6 @@ class Script(default.Script):
                 #
                 _("Clears the dynamic row headers"))
 
-        self.inputEventHandlers["panBrailleLeftHandler"] = \
-            input_event.InputEventHandler(
-                Script.panBrailleLeft,
-                # Translators: a refreshable braille display is an
-                # external hardware device that presents braille
-                # character to the user.  There are a limited number
-                # of cells on the display (typically 40 cells).  Orca
-                # provides the feature to build up a longer logical
-                # line and allow the user to press buttons on the
-                # braille display so they can pan left and right over
-                # this line.
-                #
-                _("Pans the braille display to the left."),
-                False) # Do not enable learn mode for this action
-
-        self.inputEventHandlers["panBrailleRightHandler"] = \
-            input_event.InputEventHandler(
-                Script.panBrailleRight,
-                # Translators: a refreshable braille display is an
-                # external hardware device that presents braille
-                # character to the user.  There are a limited number
-                # of cells on the display (typically 40 cells).  Orca
-                # provides the feature to build up a longer logical
-                # line and allow the user to press buttons on the
-                # braille display so they can pan left and right over
-                # this line.
-                #
-                _("Pans the braille display to the right."),
-                False) # Do not enable learn mode for this action
-
     def getAppKeyBindings(self):
         """Returns the application-specific keybindings for this script."""
 
@@ -808,52 +778,6 @@ class Script(default.Script):
 
         return True
 
-    def panBrailleLeft(self, inputEvent=None, panAmount=0):
-        """In document content, we want to use the panning keys to browse the
-        entire document.
-        """
-
-        if self.flatReviewContext \
-           or not self.isBrailleBeginningShowing() \
-           or self.isSpreadSheetCell(orca_state.locusOfFocus):
-            return default.Script.panBrailleLeft(self, inputEvent, panAmount)
-
-        obj = self.utilities.findPreviousObject(orca_state.locusOfFocus)
-        orca.setLocusOfFocus(None, obj, notifyScript=False)
-        self.updateBraille(obj)
-
-        # Hack: When panning to the left in a document, we want to start at
-        # the right/bottom of each new object. For now, we'll pan there.
-        # When time permits, we'll give our braille code some smarts.
-        while self.panBrailleInDirection(panToLeft=False):
-            pass
-        self.refreshBraille(False)
-
-        return True
-
-    def panBrailleRight(self, inputEvent=None, panAmount=0):
-        """In document content, we want to use the panning keys to browse the
-        entire document.
-        """
-
-        if self.flatReviewContext \
-           or not self.isBrailleEndShowing() \
-           or self.isSpreadSheetCell(orca_state.locusOfFocus):
-            return default.Script.panBrailleRight(self, inputEvent, panAmount)
-
-        obj = self.utilities.findNextObject(orca_state.locusOfFocus)
-        orca.setLocusOfFocus(None, obj, notifyScript=False)
-        self.updateBraille(obj)
-
-        # Hack: When panning to the right in a document, we want to start at
-        # the left/top of each new object. For now, we'll pan there. When time
-        # permits, we'll give our braille code some smarts.
-        while self.panBrailleInDirection(panToLeft=True):
-            pass
-        self.refreshBraille(False)
-
-        return True
-
     def presentInputLine(self, inputEvent):
         """Presents the contents of the spread sheet input line (assuming we
         have a handle to it - generated when we first focus on a spread
@@ -1210,7 +1134,7 @@ class Script(default.Script):
             if self.utilities.linkIndex(obj, i) >= 0:
                 voice = voices[settings.HYPERLINK_VOICE]
                 break
-            elif word.decode("UTF-8").isupper():
+            elif word.isupper():
                 voice = voices[settings.UPPERCASE_VOICE]
             else:
                 voice = voices[settings.DEFAULT_VOICE]
@@ -1350,12 +1274,12 @@ class Script(default.Script):
             hypertext = None
 
         if not hypertext or (hypertext.getNLinks() == 0):
-            result = self.speechGenerator.generateTextIndentation( \
-              event.source, line=textToSpeak.encode("UTF-8"))
+            result = self.speechGenerator.generateTextIndentation(
+              event.source, line=textToSpeak)
             if result:
                 speech.speak(result[0])
 
-            speech.speak(textToSpeak.encode("UTF-8"), None, False)
+            speech.speak(textToSpeak, None, False)
         else:
             started = False
             startOffset = 0
@@ -1364,8 +1288,7 @@ class Script(default.Script):
                     if started:
                         endOffset = i
                         self.sayWriterWord(event.source,
-                            textToSpeak[startOffset:endOffset+1].encode( \
-                                                                "UTF-8"),
+                            textToSpeak[startOffset:endOffset+1],
                             startOffset, endOffset)
                         startOffset = i
                         started = False
@@ -1377,8 +1300,7 @@ class Script(default.Script):
             if started:
                 endOffset = len(textToSpeak)
                 self.sayWriterWord(event.source,
-                    textToSpeak[startOffset:endOffset].encode("UTF-8"),
-                    startOffset, endOffset)
+                    textToSpeak[startOffset:endOffset], startOffset, endOffset)
 
     def locusOfFocusChanged(self, event, oldLocusOfFocus, newLocusOfFocus):
         """Called when the visual object with focus changes.
@@ -1429,7 +1351,7 @@ class Script(default.Script):
                    "StarOffice.locusOfFocusChanged - Writer: text paragraph.")
 
                 result = self.getTextLineAtCaret(event.source)
-                textToSpeak = result[0].decode("UTF-8")
+                textToSpeak = result[0]
                 self._speakWriterText(event, textToSpeak)
                 self.displayBrailleForObject(event.source)
                 return
@@ -1719,7 +1641,8 @@ class Script(default.Script):
             # If it is, we want to speak the misspelled word and context
             # after we've spoken the window name.
             #
-            if event.source.getRole() == pyatspi.ROLE_DIALOG \
+            if event.source \
+               and event.source.getRole() == pyatspi.ROLE_DIALOG \
                and event.source.childCount \
                and event.source[0].getRole() == pyatspi.ROLE_OPTION_PANE:
                 self.readMisspeltWord(event, event.source)
@@ -2221,8 +2144,7 @@ class Script(default.Script):
                 focusRole = orca_state.locusOfFocus.getRole()
                 if focusRole != pyatspi.ROLE_UNKNOWN and keyString == "Return":
                     result = self.utilities.substring(event.source, 0, -1)
-                    line = result.decode("UTF-8")
-                    self.echoPreviousWord(event.source, len(line))
+                    self.echoPreviousWord(event.source, len(result))
                     return
 
         # Otherwise, if the object is losing focus, then just ignore this event.
@@ -2269,8 +2191,7 @@ class Script(default.Script):
                 return
 
             result = self.utilities.substring(event.source, 0, -1)
-            textToSpeak = result.decode("UTF-8")
-            self._speakWriterText(event, textToSpeak)
+            self._speakWriterText(event, result)
             self.displayBrailleForObject(event.source)
         else:
             # The lists and combo boxes in the Formatting toolbar emit
@@ -2332,7 +2253,7 @@ class Script(default.Script):
         if isinstance(orca_state.lastInputEvent,
                         input_event.MouseButtonEvent) and \
              orca_state.lastInputEvent.button == "2":
-            if text.decode("UTF-8").isupper():
+            if text.isupper():
                 speech.speak(text, self.voices[settings.UPPERCASE_VOICE])
             else:
                 speech.speak(text)
@@ -2366,15 +2287,9 @@ class Script(default.Script):
 
                 # Sometimes we get the trailing line-feed -- remove it
                 #
-                content = lineString.decode("UTF-8")
-                if content[-1:] == "\n":
-                    content = content[:-1]
+                if lineString[-1:] == "\n":
+                    lineString = lineString[:-1]
 
-                return [content.encode("UTF-8"), 0, startOffset]
-
-        textLine = default.Script.getTextLineAtCaret(self, obj, offset)
-        if not obj.getState().contains(pyatspi.STATE_FOCUSED):
-            textLine[0] = self.utilities.displayedText(obj)
-
-        return textLine
+                return [lineString, 0, startOffset]
 
+        return default.Script.getTextLineAtCaret(self, obj, offset)
